@@ -55,12 +55,12 @@ static int
 named_arg_compare (const void *p1, const void *p2)
 {
   return strcmp (((const struct named_arg *) p1)->name,
-		 ((const struct named_arg *) p2)->name);
+                 ((const struct named_arg *) p2)->name);
 }
 
 static void *
 format_parse (const char *format, bool translated, char *fdi,
-	      char **invalid_reason)
+              char **invalid_reason)
 {
   const char *const format_start = format;
   struct spec spec;
@@ -74,45 +74,45 @@ format_parse (const char *format, bool translated, char *fdi,
   for (; *format != '\0';)
     if (*format++ == '{')
       {
-	const char *f = format;
-	char c;
+        const char *f = format;
+        char c;
 
-	c = *f;
-	if ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') || c == '_')
-	  {
-	    do
-	      c = *++f;
-	    while ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') || c == '_'
-		   || (c >= '0' && c <= '9'));
-	    if (c == '}')
-	      {
-		/* A directive.  */
-		char *name;
-		const char *name_start = format;
-		const char *name_end = f;
-		size_t n = name_end - name_start;
+        c = *f;
+        if ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') || c == '_')
+          {
+            do
+              c = *++f;
+            while ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') || c == '_'
+                   || (c >= '0' && c <= '9'));
+            if (c == '}')
+              {
+                /* A directive.  */
+                char *name;
+                const char *name_start = format;
+                const char *name_end = f;
+                size_t n = name_end - name_start;
 
-		FDI_SET (format - 1, FMTDIR_START);
+                FDI_SET (format - 1, FMTDIR_START);
 
-		name = XNMALLOC (n + 1, char);
-		memcpy (name, name_start, n);
-		name[n] = '\0';
+                name = XNMALLOC (n + 1, char);
+                memcpy (name, name_start, n);
+                name[n] = '\0';
 
-		spec.directives++;
+                spec.directives++;
 
-		if (spec.allocated == spec.named_arg_count)
-		  {
-		    spec.allocated = 2 * spec.allocated + 1;
-		    spec.named = (struct named_arg *) xrealloc (spec.named, spec.allocated * sizeof (struct named_arg));
-		  }
-		spec.named[spec.named_arg_count].name = name;
-		spec.named_arg_count++;
+                if (spec.allocated == spec.named_arg_count)
+                  {
+                    spec.allocated = 2 * spec.allocated + 1;
+                    spec.named = (struct named_arg *) xrealloc (spec.named, spec.allocated * sizeof (struct named_arg));
+                  }
+                spec.named[spec.named_arg_count].name = name;
+                spec.named_arg_count++;
 
-		FDI_SET (f, FMTDIR_END);
+                FDI_SET (f, FMTDIR_END);
 
-		format = ++f;
-	      }
-	  }
+                format = ++f;
+              }
+          }
       }
 
   /* Sort the named argument array, and eliminate duplicates.  */
@@ -121,18 +121,18 @@ format_parse (const char *format, bool translated, char *fdi,
       unsigned int i, j;
 
       qsort (spec.named, spec.named_arg_count, sizeof (struct named_arg),
-	     named_arg_compare);
+             named_arg_compare);
 
       /* Remove duplicates: Copy from i to j, keeping 0 <= j <= i.  */
       for (i = j = 0; i < spec.named_arg_count; i++)
-	if (j > 0 && strcmp (spec.named[i].name, spec.named[j-1].name) == 0)
-	  free (spec.named[i].name);
-	else
-	  {
-	    if (j < i)
-	      spec.named[j].name = spec.named[i].name;
-	    j++;
-	  }
+        if (j > 0 && strcmp (spec.named[i].name, spec.named[j-1].name) == 0)
+          free (spec.named[i].name);
+        else
+          {
+            if (j < i)
+              spec.named[j].name = spec.named[i].name;
+            j++;
+          }
       spec.named_arg_count = j;
     }
 
@@ -150,7 +150,7 @@ format_free (void *descr)
     {
       unsigned int i;
       for (i = 0; i < spec->named_arg_count; i++)
-	free (spec->named[i].name);
+        free (spec->named[i].name);
       free (spec->named);
     }
   free (spec);
@@ -166,8 +166,8 @@ format_get_number_of_directives (void *descr)
 
 static bool
 format_check (void *msgid_descr, void *msgstr_descr, bool equality,
-	      formatstring_error_logger_t error_logger,
-	      const char *pretty_msgstr)
+              formatstring_error_logger_t error_logger,
+              const char *pretty_msgid, const char *pretty_msgstr)
 {
   struct spec *spec1 = (struct spec *) msgid_descr;
   struct spec *spec2 = (struct spec *) msgstr_descr;
@@ -180,33 +180,33 @@ format_check (void *msgid_descr, void *msgstr_descr, bool equality,
       unsigned int n2 = spec2->named_arg_count;
 
       /* Check the argument names in spec1 are contained in those of spec2.
-	 Additional arguments in spec2 are allowed; they expand to themselves
-	 (including the surrounding braces) at runtime.
-	 Both arrays are sorted.  We search for the differences.  */
+         Additional arguments in spec2 are allowed; they expand to themselves
+         (including the surrounding braces) at runtime.
+         Both arrays are sorted.  We search for the differences.  */
       for (i = 0, j = 0; i < n1 || j < n2; )
-	{
-	  int cmp = (i >= n1 ? 1 :
-		     j >= n2 ? -1 :
-		     strcmp (spec1->named[i].name, spec2->named[j].name));
+        {
+          int cmp = (i >= n1 ? 1 :
+                     j >= n2 ? -1 :
+                     strcmp (spec1->named[i].name, spec2->named[j].name));
 
-	  if (cmp > 0)
-	    j++;
-	  else if (cmp < 0)
-	    {
-	      if (equality)
-		{
-		  if (error_logger)
-		    error_logger (_("a format specification for argument '%s' doesn't exist in '%s'"),
-				  spec1->named[i].name, pretty_msgstr);
-		  err = true;
-		  break;
-		}
-	      else
-		i++;
-	    }
-	  else
-	    j++, i++;
-	}
+          if (cmp > 0)
+            j++;
+          else if (cmp < 0)
+            {
+              if (equality)
+                {
+                  if (error_logger)
+                    error_logger (_("a format specification for argument '%s' doesn't exist in '%s'"),
+                                  spec1->named[i].name, pretty_msgstr);
+                  err = true;
+                  break;
+                }
+              else
+                i++;
+            }
+          else
+            j++, i++;
+        }
     }
 
   return err;
@@ -246,7 +246,7 @@ format_print (void *descr)
   for (i = 0; i < spec->named_arg_count; i++)
     {
       if (i > 0)
-	printf (", ");
+        printf (", ");
       printf ("'%s'", spec->named[i].name);
     }
   printf ("}");
@@ -265,9 +265,9 @@ main ()
 
       line_len = getline (&line, &line_size, stdin);
       if (line_len < 0)
-	break;
+        break;
       if (line_len > 0 && line[line_len - 1] == '\n')
-	line[--line_len] = '\0';
+        line[--line_len] = '\0';
 
       invalid_reason = NULL;
       descr = format_parse (line, false, NULL, &invalid_reason);
@@ -275,7 +275,7 @@ main ()
       format_print (descr);
       printf ("\n");
       if (descr == NULL)
-	printf ("%s\n", invalid_reason);
+        printf ("%s\n", invalid_reason);
 
       free (invalid_reason);
       free (line);
